==> deepin-system-monitor_6.0.7.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="130"/>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="180"/>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="216"/>
        <location filename="../gui/cpu_widget.cpp" line="217"/>
        <source>Utilization</source>
        <translation>Hasznosítás</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="228"/>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="258"/>
        <source>Read</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="259"/>
        <source>Write</source>
        <translation>Írás</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="42"/>
        <source>System</source>
        <translation>Rendszer</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="48"/>
        <source>Display shortcuts</source>
        <translation>Parancsikonok megjelenítése</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="152"/>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="179"/>
        <location filename="../gui/memory_widget.cpp" line="188"/>
        <source>Swap</source>
        <translation>Cserehely</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="180"/>
        <source>Not enabled</source>
        <translation>Nincs engedélyezve</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="259"/>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="260"/>
        <source>Total received</source>
        <translation>Összes beérkezett</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="262"/>
        <source>Total sent</source>
        <translation>Összes küldött</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="261"/>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="232"/>
        <location filename="../gui/net_widget.cpp" line="235"/>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="67"/>
        <source>Very high</source>
        <translation>Nagyon magas</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="68"/>
        <source>High</source>
        <translation>Magas</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="69"/>
        <source>Normal</source>
        <translation>Normál</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="70"/>
        <source>Low</source>
        <translation>Alacsony</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="71"/>
        <source>Very low</source>
        <translation>Nagyon alacsony</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="72"/>
        <source>Custom</source>
        <translation>Egyéni</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="73"/>
        <source>Invalid</source>
        <translation>Érvénytelen</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="162"/>
        <source>Failed to end process</source>
        <translation>Nem sikerült befejezni a folyamatokat</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="165"/>
        <source>Failed to pause process</source>
        <translation>Nem sikerült szüneteltetni a folyamatot</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to resume process</source>
        <translation>Nem sikerült folytatni a folyamatot</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to kill process</source>
        <translation>Nem sikerült kilőni a folyamatot</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Unknown error</source>
        <translation>Ismeretlen hiba</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="224"/>
        <source>Failed in sending signal to process</source>
        <translation>Nem sikerült elküldeni a jelet a feldolgozáshoz</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="175"/>
        <source>No response</source>
        <translation>Nem válaszol</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="180"/>
        <source>Suspend</source>
        <translation>Felfüggesztés</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="96"/>
        <location filename="../process/process_name.cpp" line="103"/>
        <location filename="../process/process_name.cpp" line="106"/>
        <source>Tray</source>
        <translation>Tálca</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="76"/>
        <source>End process</source>
        <translation>Folyamat befejezése</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="82"/>
        <source>Suspend process</source>
        <translation>Folyamat felfüggesztése</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="88"/>
        <source>Resume process</source>
        <translation>Folyamat folytatása</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="93"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Kill process</source>
        <translation>Folyamat kilövése</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="31"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="33"/>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="35"/>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="37"/>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Shared memory</source>
        <translation>Megosztott memória</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="39"/>
        <source>Virtual memory</source>
        <translation>Virtuális memória</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="41"/>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="43"/>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="45"/>
        <source>Disk read</source>
        <translation>Lemez olvasás</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="47"/>
        <source>Disk write</source>
        <translation>Lemez írás</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="49"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="51"/>
        <source>Nice</source>
        <translation>Nagyszerű</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="53"/>
        <source>Priority</source>
        <translation>Prioritás</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="65"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="72"/>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="182"/>
        <location filename="../gui/process_widget.cpp" line="185"/>
        <source>Processes</source>
        <translation>Folyamatok</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="267"/>
        <source>Not support</source>
        <translation>Nem támogatott</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <source>Start</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="123"/>
        <source>Restart</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="128"/>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="69"/>
        <source>Force end application</source>
        <translation>Kényszerített alkalmazás leállítás</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="54"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="63"/>
        <source>Processes</source>
        <translation>Folyamatok</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <source>Services</source>
        <translation>Szolgáltatások</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_6.5.24.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="141"/>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="193"/>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="229"/>
        <location filename="../gui/cpu_widget.cpp" line="231"/>
        <location filename="../gui/cpu_widget.cpp" line="232"/>
        <source>Utilization</source>
        <translation>Hasznosítás</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="242"/>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="276"/>
        <source>Read</source>
        <translation>Olvasás</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="277"/>
        <source>Write</source>
        <translation>Írás</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="178"/>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="210"/>
        <location filename="../gui/memory_widget.cpp" line="218"/>
        <source>Swap</source>
        <translation>Cserehely</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="211"/>
        <source>Not enabled</source>
        <translation>Nincs engedélyezve</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="271"/>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="272"/>
        <source>Total received</source>
        <translation>Összes beérkezett</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="274"/>
        <source>Total sent</source>
        <translation>Összes küldött</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="273"/>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="241"/>
        <location filename="../gui/net_widget.cpp" line="243"/>
        <location filename="../gui/net_widget.cpp" line="247"/>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="54"/>
        <source>Very high</source>
        <translation>Nagyon magas</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="55"/>
        <source>High</source>
        <translation>Magas</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="56"/>
        <source>Normal</source>
        <translation>Normál</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="57"/>
        <source>Low</source>
        <translation>Alacsony</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="58"/>
        <source>Very low</source>
        <translation>Nagyon alacsony</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="59"/>
        <source>Custom</source>
        <translation>Egyéni</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="60"/>
        <source>Invalid</source>
        <translation>Érvénytelen</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to end process</source>
        <translation>Nem sikerült befejezni a folyamatokat</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to pause process</source>
        <translation>Nem sikerült szüneteltetni a folyamatot</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Failed to resume process</source>
        <translation>Nem sikerült folytatni a folyamatot</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="177"/>
        <source>Failed to kill process</source>
        <translation>Nem sikerült kilőni a folyamatot</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="180"/>
        <source>Unknown error</source>
        <translation>Ismeretlen hiba</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="239"/>
        <source>Failed in sending signal to process</source>
        <translation>Nem sikerült elküldeni a jelet a feldolgozáshoz</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="174"/>
        <source>No response</source>
        <translation>Nem válaszol</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="179"/>
        <source>Suspend</source>
        <translation>Felfüggesztés</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Megosztott memória</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Virtuális memória</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Feltöltés</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Lemez olvasás</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Lemez írás</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nagyszerű</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Prioritás</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="219"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="225"/>
        <source>CPU</source>
        <translation>Processzor</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="203"/>
        <location filename="../gui/process_widget.cpp" line="205"/>
        <location filename="../gui/process_widget.cpp" line="209"/>
        <source>Processes</source>
        <translation>Folyamatok</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="253"/>
        <source>Not support</source>
        <translation>Nem támogatott</translation>
    </message>
</context>
</TS>
